#!/bin/sh

# Must run as root
if [ $(id -u) -ne 0 ]
  then echo "Please run as root or use sudo"
  exit 1
fi

EXT=deb
HIGLIGHT_PURPLE="\033[35m"
HIGLIGHT_GREEN="\033[32m"
HIGLIGHT_RED="\033[31m"
END_HIGHLIGHT="\033[0m"

# Check if the required packages are installed or not, and build a list of required packages to install
for package in *.${EXT};do
   required_pkg=$(echo "${package}" | cut -d'_' -f1)
   pkg_ok="$(dpkg-query -W --showformat='${Status}\n' $required_pkg 2>/dev/null | grep 'install ok installed')"
   if [ -z "$pkg_ok" ];then
      APT_PACKAGES="$APT_PACKAGES ${required_pkg}"
      # Fall-back package list to install from the local copy in case apt-get has no network access or in case it fails.
      PACKAGES="$PACKAGES ${package}"
      echo "Required To Install: ${HIGLIGHT_PURPLE}${required_pkg}${END_HIGHLIGHT}"
   fi
done

# Install the required packages.
# First try downloading the latest ones from the Internet.
# If there is a problem installing from the Internet, install the supplied ones instead.
if [ ! -z "$PACKAGES" ]; then
  (apt-get update && apt-get install $(echo "$APT_PACKAGES") -y) || dpkg -i $(echo "$PACKAGES")
fi


# Check if the packages are installed
for package in *.${EXT};do
   required_pkg=$(echo "${package}" | cut -d'_' -f1)
   pkg_ok="$(dpkg-query -W --showformat='${Status}\n' $required_pkg 2>/dev/null | grep 'install ok installed')"
   if [ -z "$pkg_ok" ];then
      echo "Not Installed: ${HIGLIGHT_RED}${required_pkg}${END_HIGHLIGHT}"
      FAILED=true;
   else
      echo "Installed: ${HIGLIGHT_GREEN}${required_pkg}${END_HIGHLIGHT}"
   fi
done

# Exit with error if there is a failed-to-install package(s)
if [ -z $FAILED ];then
  echo "${HIGLIGHT_GREEN}All packages have been succesfully installed!${END_HIGHLIGHT}"
  exit 0
else
  echo "${HIGLIGHT_RED}Failed to install some or all of the packages!${END_HIGHLIGHT}"
  exit 1
fi

